# TestPointResultModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**test_point_id** | **str, none_type** |  | [optional] 
**aggregated_outcome** | **str, none_type** |  | [optional] 
**work_item_global_id** | **int, none_type** |  | [optional] 
**work_item_name** | **str, none_type** |  | [optional] 
**configuration_name** | **str, none_type** |  | [optional] 
**test_results** | [**[TestResultShortModel], none_type**](TestResultShortModel.md) |  | [optional] 
**attachments** | [**[AttachmentModel], none_type**](AttachmentModel.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


